@@ -32,6 +32,7 @@
 #include <stdlib.h>
 #include <assert.h>
 #include <glib.h>
+#include <limits.h>
 #include "vanessa_logger.h"
 #include "l7vs.h"
 
@@ -585,6 +586,10 @@ l7vs_conn_close_rsock(struct l7vs_conn *conn)
                                             conn->dest, conn->dest->nactive,
                                             conn->dest->nactive - 1);
                 conn->dest->nactive--;
+                conn->dest->ninact++;
+                if(conn->dest->ninact == INT_MAX) {
+                        conn->dest->ninact = 0;
+                }
         }
         l7vs_iomux_remove(&conn->riom);
         close(conn->riom.fd);
