@@ -496,7 +496,17 @@ get_servicename(struct sockaddr_in *addr, int isnumeric)
         ret = getnameinfo((struct sockaddr *)addr, sizeof(*addr),
                           hostname, sizeof(hostname),
                           portname, sizeof(portname), flags);
-        if (ret != 0) {
+	if (ret == EAI_AGAIN) {
+		flags = flags | NI_NUMERICHOST;
+		ret = getnameinfo((struct sockaddr *)addr, sizeof(*addr),
+				hostname, sizeof(hostname),
+				portname, sizeof(portname), flags);
+		if (ret != 0) {
+			VANESSA_LOGGER_ERR_UNSAFE("getnameinfo: %s",
+						gai_strerror(ret));
+			return NULL;
+		}
+	} else if (ret != 0) {
                 VANESSA_LOGGER_ERR_UNSAFE("getnameinfo: %s",
                                           gai_strerror(ret));
                 return NULL;
@@ -848,11 +858,12 @@ retry:
                 if (srvname == NULL) {
                         break;
                 }
-                printf("  -> %-28s %-7s %-6d %-10d 0\n",
+                printf("  -> %-28s %-7s %-6d %-10d %-10d\n",
                        srvname,
                        "Masq",
                        darg[i].weight,
-                       darg[i].nactive);
+                       darg[i].nactive,
+		       darg[i].ninact);
                 free(srvname);
         }
 
@@ -1253,3 +1264,4 @@ void list_ss(struct sockaddr_in vaddr)
 	}
 }
 
+
